%define anolis_release 3

%bcond_with bootstrap
%bcond_with pacrunner

Name:           libproxy
Version:        0.4.18
Release:        %{anolis_release}%{?dist}
Summary:        A library that provides automatic proxy configuration management.
License:        LGPLv2+
URL:            https://libproxy.github.io/libproxy/
Source0:        https://github.com/libproxy/%{name}/releases/download/%{name}-%{version}.tar.xz
Source1:        proxy.1

BuildRequires:  gcc gcc-c++ cmake >= 2.6.0 
BuildRequires:  automake autoconf

%if %{without bootstrap}
BuildRequires:  pkgconfig(gio-2.0) >= 2.26 pkgconfig(libnm) pkgconfig(dbus-1) pkgconfig(duktape)  
BuildRequires:  python3-devel
%endif


%description
libproxy is a library that provides automatic proxy configuration management.

%package bin
Summary:        Binary to test %{name}
Requires:       %{name} = %{version}-%{release}

%description bin
The libproxy-bin package contains the proxy binary for libproxy.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%if %{without bootstrap}
%package -n python3-%{name}
Summary:        Binding for libproxy and python3
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch
%{?python_provide:%python_provide python3-%{name}}

%description -n python3-%{name}
The python3 binding for libproxy

%package        gnome
Summary:        Plugin for %{name} and gnome
Requires:       %{name} = %{version}-%{release}

%description    gnome
The libproxy-gnome package contains the libproxy plugin for gnome.

%package        duktape            
Summary:        Plugin for libproxy and duktape            
Requires:       %{name} = %{version}-%{release}            
Provides:       %{name}-pac = %{version}-%{release}            
Obsoletes:      %{name}-mozjs <= %{EVR}            
Obsoletes:      %{name}-webkitgtk4 <= %{EVR}            

%description    duktape            
The libproxy-duktape package contains the libproxy plugin for            
duktape.

%package        networkmanager
Summary:        Plugin for %{name} and networkmanager
Requires:       %{name} = %{version}-%{release}

%description    networkmanager
The libproxy-networkmanager package contains the libproxy plugin for networkmanager.

if %{with pacrunner}
%package        pacrunner
Summary:        Plugin for %{name} and PacRunner
Requires:       %{name} = %{version}-%{release}
Provides:       %{name}-pac = %{version}-%{release}
Requires:       pacrunner

%description    pacrunner
The %{name}-pacrunner package contains the %{name} plugin for
ConnMan's PacRunner.
%endif

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1

%build
export CXXFLAGS="-std=c++14 $RPM_OPT_FLAGS"
%cmake \
  -DMODULE_INSTALL_DIR=%{_libdir}/%{name}/%{version}/modules \
  -DBIPR=OFF \
  -DWITH_GNOME=OFF \
  -DWITH_MOZJS=OFF \
  -DWITH_PERL=OFF \
  -DWITH_PYTHON2=OFF \
  -DWITH_WEBKIT=OFF \
  -DWITH_WEBKIT3=OFF \
  -DWITH_KDE=OFF \
%if %{without bootstrap}
  -DWITH_DUKTAPE=ON \
  -DWITH_GNOME3=ON \
  -DWITH_PYTHON3=ON \
%else
  -DWITH_DUKTAPE=OFF \
  -DWITH_GNOME3=OFF \
  -DWITH_PYTHON3=OFF \
%endif
  %{nil}
%cmake_build

%install
%cmake_install
mkdir -p %{buildroot}%{_libdir}/%{name}/%{version}/modules
mkdir -p %{buildroot}/%{_mandir}/man1
install -m 0644 -p %{SOURCE1} %{buildroot}/%{_mandir}/man1/proxy.1

%if %{without pacrunner}
rm -rf %{buildroot}%{_libdir}/%{name}/%{version}/modules/config_pacrunner.so
%endif


%check
%ctest

%files
%license COPYING
%{_libdir}/libproxy.so.*
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/%{version}
%dir %{_libdir}/%{name}/%{version}/modules

%files bin
%{_bindir}/proxy
%{_mandir}/man1/proxy.1*

%if %{without bootstrap}
%files -n python3-%{name}
%{python3_sitelib}/__pycache__/*
%{python3_sitelib}/%{name}.*

%files gnome
%{_libdir}/%{name}/%{version}/modules/config_gnome3.so
%{_libexecdir}/pxgsettings

%files networkmanager
%{_libdir}/%{name}/%{version}/modules/network_networkmanager.so

%files duktape
%{_libdir}/%{name}/%{version}/modules/pacrunner_duktape.so

%if %{with pacrunner}
%files pacrunner
%{_libdir}/%{name}/%{version}/modules/config_pacrunner.so
%endif
%endif

%files devel
%{_includedir}/proxy.h
%{_libdir}/*.so
%{_libdir}/pkgconfig/libproxy-1.0.pc
%{_datadir}/cmake/Modules/Findlibproxy.cmake

%files doc
%doc AUTHORS README


%changelog
* Mon Apr 10 2023 chen_yu_ao <m15927509890@163.com> - 0.4.18-3
- change spec file format

* Sun Feb 12 2023 Funda Wang <fundawang@yeah.net> - 0.4.18-2
- Use duktape instead of webkitgtk as js engine

* Wed Sep 21 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.4.18-1
- update to 0.4.18

* Thu Apr 07 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.4.17-1
- Init from upstream version 0.4.17

